changeset 16269:f5437f2db322

mx fsckprojects: do not traverse lib subdirectory
author Andreas Woess <andreas.woess@jku.at>
date Fri, 27 Jun 2014 17:24:28 +0200
parents 0e092c1ecd64
children d56a09df1a1f
files mxtool/mx.py
diffstat 1 files changed, 2 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/mxtool/mx.py	Thu Jun 26 18:04:47 2014 +0200
+++ b/mxtool/mx.py	Fri Jun 27 17:24:28 2014 +0200
@@ -4163,9 +4163,8 @@
         projectDirs = [p.dir for p in suite.projects]
         for dirpath, dirnames, files in os.walk(suite.dir):
             if dirpath == suite.dir:
-                # no point in traversing .hg
-                if '.hg' in dirnames:
-                    dirnames.remove('.hg')
+                # no point in traversing .hg or lib/
+                dirnames[:] = [d for d in dirnames if d not in ['.hg', 'lib']]
             elif dirpath in projectDirs:
                 # don't traverse subdirs of an existing project in this suite
                 dirnames[:] = []